@@ -69,7 +69,11 @@ class light_curve(observation):
             self._frac_exp_=np.ones(len(self._rates_))
 
         self._data_header_ = ff[data_ind].header
-        self._gti_header_ = ff[gti_ind].header
+        try:
+            self._gti_header_ = ff[gti_ind].header
+        except:
+            logger.warning("Not found GTI, ignoring")
+            self._gti_header_ = None
 
         self._timeref_ = ff[data_ind].header['TIMEREF']
         self._timesys_ = ff[data_ind].header['TIMESYS']
@@ -78,7 +82,12 @@ class light_curve(observation):
         except:
             logger.debug("Try to use MJDREFI and MJDREFF")
             self._mjdref_ = ff[data_ind].header['MJDREFI'] + ff[data_ind].header['MJDREFF']
-        self._exposure_ = ff[data_ind].header['EXPOSURE']
+
+        try:
+            self._exposure_ = ff[data_ind].header['EXPOSURE']
+        except:
+            logger.warning("No Exposure")
+            self._exposure_ = -1
 
         #TODO Use this value
         try:
@@ -108,11 +117,15 @@ class light_curve(observation):
             logger.info("Initializing delta_times from TIMEDEL")
             self._dtimes_ = np.ones(len(self._times_)) * self._timedel_
 
-        self._gti_start_ = ff[gti_ind].data['START']
-        self._gti_stop_ = ff[gti_ind].data['STOP']
+        if self._gti_header_ is not None:
+            self._gti_start_ = self._gti_header_.data['START']
+            self._gti_stop_ = self._gti_header_.data['STOP']
+        else:
+            logger.warning('No GTI, using data start and stop')
+            self._gti_start_ = np.array([self._tstart_])
+            self._gti_stop_ = np.array([self._tstop_])
 
         ff.close()
-
         self.dump_info()
 
     def dump_info(self):
